@@ -1,6 +1,7 @@
 from tradingfeatures.apis.bitfinex import bitfinex
 from tradingfeatures.apis.bitstamp import bitstamp
 from tradingfeatures.apis.bitmex import bitmex
-from tradingfeatures.apis.bitmex_v2 import bitmex_v2
 from tradingfeatures.apis.binance import binance
-from tradingfeatures.apis.okex import okex
\ No newline at end of file
+# from tradingfeatures.apis.okex import okex
+
+# from tradingfeatures.apis.bitmex_v3 import bitmexV3
\ No newline at end of file
